@@ -24,8 +24,9 @@ AUTOMATION_TYPES = [
     "detect_sentiment",
     "tag_short_text",
     "tag_entire_images",
-    "item_recommendation",
-    "user_recommendation",
+    "recommend_items_to_people",
+    "recommend_people_to_each_other",
+    "recommend_people_from_two_groups_to_each_other",
 ]
 
 
@@ -33,15 +34,19 @@ def construct(automation_type, automation_id, automation_api):
     from .detect_sentiment import DetectSentiment
     from .tag_short_text import TagShortText
     from .tag_entire_images import TagEntireImages
-    from .user_recommendation import UserRecommendation
-    from .item_recommendation import ItemRecommendation
+    from .recommend_people_to_each_other import RecommendPeopleToEachOther
+    from .recommend_people_from_two_groups_to_each_other import (
+        RecommendPeopleFromTwoGroupsToEachOther,
+    )
+    from .recommend_items_to_people import RecommendItemsToPeople
 
     AUTOMATION_CLASSES = {
         "detect_sentiment": DetectSentiment,
         "tag_short_text": TagShortText,
         "tag_entire_images": TagEntireImages,
-        "item_recommendation": ItemRecommendation,
-        "user_recommendation": UserRecommendation,
+        "recommend_items_to_people": RecommendItemsToPeople,
+        "recommend_people_to_each_other": RecommendPeopleToEachOther,
+        "recommend_people_from_two_groups_to_each_other": RecommendPeopleFromTwoGroupsToEachOther,
     }
 
     if automation_type not in AUTOMATION_CLASSES:
@@ -77,9 +82,9 @@ class Automation:
                 "automations", self._automation_id, "definition", "ontology"
             ),
             ontology,
-            error_msg=f"Unknown error in updating ontology.",
+            error_msg="Unknown error in updating ontology.",
             network_errors={
-                400: f"Please check the ontology to be updated.",
+                400: "Please check the ontology to be updated.",
                 403: f"Could not connect to automation {self._automation_id}. Please check the API key.",
             },
         )
@@ -88,9 +93,9 @@ class Automation:
         job = self._api.post(
             self._api.endpoint("automations", self._automation_id, "jobs"),
             job,
-            error_msg=f"Unknown error in job.",
+            error_msg="Unknown error in job.",
             network_errors={
-                400: f"Please check the job parameters.",
+                400: "Please check the job parameters.",
                 403: f"Could not connect to automation {self._automation_id}. Please check the API key.",
             },
         )
@@ -100,9 +105,9 @@ class Automation:
                 self._api.endpoint(
                     "automations", self._automation_id, "jobs", job["_id"]
                 ),
-                error_msg=f"Unknown error in job.",
+                error_msg="Unknown error in job.",
                 network_errors={
-                    400: f"Please check the request.",
+                    400: "Please check the request.",
                     403: f"Could not connect to automation {self._automation_id}. Please check the API key.",
                 },
             )
@@ -122,9 +127,9 @@ class Automation:
         job = self._api.post(
             self._api.endpoint("automations", self._automation_id, "jobs"),
             job,
-            error_msg=f"Unknown error in job.",
+            error_msg="Unknown error in job.",
             network_errors={
-                400: f"Please check the job parameters.",
+                400: "Please check the job parameters.",
                 403: f"Could not connect to automation {self._automation_id}. Please check the API key.",
             },
         )
@@ -134,9 +139,9 @@ class Automation:
         return self._api.post(
             self._api.endpoint("automations", self._automation_id, "inferences", task),
             obj,
-            error_msg=f"Unknown error in {task}.",
+            error_msg="Unknown error in {task}.",
             network_errors={
-                400: f"Please check the data uploaded.",
+                400: "Please check the data uploaded.",
                 403: f"Could not connect to automation {self._automation_id}. Please check the API key.",
             },
         )
@@ -147,9 +152,9 @@ class Automation:
     def get_job(self, job):
         return self._api.get(
             self._api.endpoint("automations", self._automation_id, "jobs", job["_id"]),
-            error_msg=f"Unknown error in job.",
+            error_msg="Unknown error in job.",
             network_errors={
-                400: f"Please check the request.",
+                400: "Please check the request.",
                 403: f"Could not connect to automation {self._automation_id}. Please check the API key.",
             },
         )
